@@ -7,11 +7,13 @@ import (
 
 type Controller struct {
 	repositoriesService RepositoriesService
+	pullRequestsService PullRequestsService
 	fs                  afero.Fs
 	cfg                 *config.Config
 	param               *ParamRun
 	cfgFinder           ConfigFinder
 	cfgReader           ConfigReader
+	logger              *Logger
 }
 
 type ConfigFinder interface {
@@ -22,13 +24,15 @@ type ConfigReader interface {
 	Read(cfg *config.Config, configFilePath string) error
 }
 
-func New(repositoriesService RepositoriesService, fs afero.Fs, cfgFinder ConfigFinder, cfgReader ConfigReader, param *ParamRun) *Controller {
+func New(repositoriesService RepositoriesService, pullRequestsService PullRequestsService, fs afero.Fs, cfgFinder ConfigFinder, cfgReader ConfigReader, param *ParamRun) *Controller {
 	return &Controller{
 		repositoriesService: repositoriesService,
+		pullRequestsService: pullRequestsService,
 		param:               param,
 		fs:                  fs,
 		cfgFinder:           cfgFinder,
 		cfgReader:           cfgReader,
 		cfg:                 &config.Config{},
+		logger:              NewLogger(param.Stderr),
 	}
 }
