@@ -2,6 +2,7 @@ package run
 
 import (
 	"context"
+	"errors"
 	"fmt"
 
 	"github.com/hashicorp/go-version"
@@ -16,6 +17,10 @@ type RepositoriesService interface {
 	ListReleases(ctx context.Context, owner, repo string, opts *github.ListOptions) ([]*github.RepositoryRelease, *github.Response, error)
 }
 
+type PullRequestsService interface {
+	CreateComment(ctx context.Context, owner, repo string, number int, comment *github.PullRequestComment) (*github.PullRequestComment, *github.Response, error)
+}
+
 func (r *RepositoriesServiceImpl) GetCommitSHA1(ctx context.Context, owner, repo, ref, lastSHA string) (string, *github.Response, error) {
 	key := fmt.Sprintf("%s/%s/%s", owner, repo, ref)
 	a, ok := r.Commits[key]
@@ -165,3 +170,32 @@ func (c *Controller) getLatestVersionFromTags(ctx context.Context, logE *logrus.
 	}
 	return latestVersion, nil
 }
+
+func (c *Controller) review(ctx context.Context, filePath string, sha string, line int, suggestion string, err error) (int, error) {
+	cmt := &github.PullRequestComment{
+		Body: github.Ptr(""),
+		Path: github.Ptr(filePath),
+		Line: github.Ptr(line),
+	}
+	if sha != "" {
+		cmt.CommitID = github.Ptr(sha)
+	}
+	const header = "Reviewed by [pinact](https://github.com/suzuki-shunsuke/pinact)"
+	switch {
+	case suggestion != "":
+		cmt.Body = github.Ptr(fmt.Sprintf("%s\n```suggestion\n%s\n```", header, suggestion))
+	case err != nil:
+		cmt.Body = github.Ptr(fmt.Sprintf("%s\n%s", header, err.Error()))
+	default:
+		return 0, errors.New("either suggestion or error must be provided")
+	}
+	_, resp, e := c.pullRequestsService.CreateComment(ctx, c.param.Review.RepoOwner, c.param.Review.RepoName, c.param.Review.PullRequest, cmt)
+	code := 0
+	if resp != nil {
+		code = resp.StatusCode
+	}
+	if e != nil {
+		return code, fmt.Errorf("create a review comment: %w", e)
+	}
+	return code, nil
+}
